@@ -1,5 +1,7 @@
-__version__ = '4.1.7'
+"""Tibia.com parsing and fetching library."""
+__version__ = '5.0.0'
 __author__ = 'Allan Galarza'
+__license__ = 'Apache-2.0 License'
 
 import logging
 
@@ -14,10 +16,12 @@ from tibiapy.forum import *
 from tibiapy.guild import *
 from tibiapy.highscores import *
 from tibiapy.kill_statistics import *
+from tibiapy.leaderboard import *
 from tibiapy.news import *
 from tibiapy.tournament import *
 from tibiapy.world import *
 from tibiapy.bazaar import *
+from tibiapy.spell import *
 from tibiapy.client import *
 
 from logging import NullHandler
