@@ -1,17 +1,19 @@
+"""Models related to the Tibia.com character page."""
 import datetime
 import re
 import urllib.parse
 from collections import OrderedDict
-from typing import List, Optional
-
-import bs4
+from typing import List, Optional, TYPE_CHECKING
 
 from tibiapy import abc
 from tibiapy.enums import AccountStatus, Sex, Vocation
 from tibiapy.errors import InvalidContent
 from tibiapy.house import CharacterHouse
-from tibiapy.utils import parse_tibia_date, parse_tibia_datetime, parse_tibiacom_content, split_list, try_datetime, \
-    try_enum
+from tibiapy.utils import (parse_popup, parse_tibia_date, parse_tibia_datetime, parse_tibiacom_content, split_list,
+                           try_datetime, try_enum)
+
+if TYPE_CHECKING:
+    import bs4
 
 # Extracts the scheduled deletion date of a character."""
 deleted_regexp = re.compile(r'([^,]+), will be deleted at (.*)')
@@ -44,7 +46,7 @@ __all__ = (
 
 
 class AccountBadge(abc.Serializable):
-    """Represents an account badge.
+    """A displayed account badge in the character's information.
 
     Attributes
     ----------
@@ -55,6 +57,7 @@ class AccountBadge(abc.Serializable):
     description: :class:`str`
         The description of the badge.
     """
+
     __slots__ = (
         "name",
         "icon_url",
@@ -71,7 +74,7 @@ class AccountBadge(abc.Serializable):
 
 
 class AccountInformation(abc.Serializable):
-    """Represents the account information of a character.
+    """Contains the information of a character's account.
 
     This is only visible if the character is not marked as hidden.
 
@@ -84,6 +87,7 @@ class AccountInformation(abc.Serializable):
     loyalty_title: :class:`str`, optional
         The loyalty title of the account, if any.
     """
+
     __slots__ = (
         "created",
         "loyalty_title",
@@ -91,7 +95,7 @@ class AccountInformation(abc.Serializable):
     )
 
     def __init__(self, created, loyalty_title=None, position=None):
-        self.created = try_datetime(created)
+        self.created: datetime.datetime = try_datetime(created)
         self.loyalty_title: Optional[str] = loyalty_title
         self.position: Optional[str] = position
 
@@ -111,6 +115,7 @@ class Achievement(abc.Serializable):
     secret: :class:`bool`
         Whether the achievement is secret or not.
     """
+
     __slots__ = (
         "name",
         "grade",
@@ -127,7 +132,7 @@ class Achievement(abc.Serializable):
 
 
 class Character(abc.BaseCharacter, abc.Serializable):
-    """Represents a Tibia character.
+    """A full character from Tibia.com, obtained from its character page.
 
     Attributes
     ----------
@@ -136,7 +141,7 @@ class Character(abc.BaseCharacter, abc.Serializable):
     traded: :class:`bool`
         If the character was traded in the last 6 months.
     deletion_date: :class:`datetime.datetime`, optional
-        The date when the character will be deleted if it is scheduled for deletion.
+        The date when the character will be deleted if it is scheduled for deletion. Will be :obj:`None` otherwise.
     former_names: :class:`list` of :class:`str`
         Previous names of the character.
     title: :class:`str`, optional
@@ -158,11 +163,11 @@ class Character(abc.BaseCharacter, abc.Serializable):
     residence: :class:`str`
         The current hometown of the character.
     married_to: :class:`str`, optional
-        The name of the character's spouse.
+        The name of the character's spouse. It will be :obj:`None` if not married.
     houses: :class:`list` of :class:`CharacterHouse`
         The houses currently owned by the character.
     guild_membership: :class:`GuildMembership`, optional
-        The guild the character is a member of.
+        The guild the character is a member of. It will be :obj:`None` if the character is not in a guild.
     last_login: :class:`datetime.datetime`, optional
         The last time the character logged in. It will be :obj:`None` if the character has never logged in.
     position: :class:`str`, optional
@@ -182,12 +187,13 @@ class Character(abc.BaseCharacter, abc.Serializable):
 
         In some cases, there are more deaths in the last 30 days than what can be displayed.
     account_information: :class:`AccountInformation`, optional
-        The character's account information, if visible.
+        The character's account information. If the character is hidden, this will be :obj:`None`.
     other_characters: :class:`list` of :class:`OtherCharacter`
         Other characters in the same account.
 
         It will be empty if the character is hidden, otherwise, it will contain at least the character itself.
     """
+
     __slots__ = (
         "name",
         "former_names",
@@ -262,34 +268,34 @@ class Character(abc.BaseCharacter, abc.Serializable):
 
     @property
     def guild_name(self) -> Optional[str]:
-        """:class:`str`: The name of the guild the character belongs to, or :obj:`None`."""
+        """:class:`str`, optional: The name of the guild the character belongs to, or :obj:`None`."""
         return self.guild_membership.name if self.guild_membership else None
 
     @property
     def guild_rank(self) -> Optional[str]:
-        """:class:`str`: The character's rank in the guild they belong to, or :obj:`None`."""
+        """:class:`str`, optional: The character's rank in the guild they belong to, or :obj:`None`."""
         return self.guild_membership.rank if self.guild_membership else None
 
     @property
-    def guild_url(self):
-        """:class:`str`: The character's rank in the guild they belong to, or :obj:`None`."""
+    def guild_url(self) -> Optional[str]:
+        """:class:`str`, optional: The character's rank in the guild they belong to, or :obj:`None`."""
         return abc.BaseGuild.get_url(self.guild_membership.name) if self.guild_membership else None
 
     @property
-    def hidden(self):
+    def hidden(self) -> bool:
         """:class:`bool`: Whether this is a hidden character or not."""
         return len(self.other_characters) == 0
 
     @property
-    def married_to_url(self):
-        """:class:`str`: The URL to the husband/spouse information page on Tibia.com, if applicable."""
+    def married_to_url(self) -> Optional[str]:
+        """:class:`str`, optional: The URL to the husband/spouse information page on Tibia.com, if applicable."""
         return self.get_url(self.married_to) if self.married_to else None
     # endregion
 
     # region Public methods
     @classmethod
     def from_content(cls, content):
-        """Creates an instance of the class from the html content of the character's page.
+        """Create an instance of the class from the html content of the character's page.
 
         Parameters
         ----------
@@ -328,8 +334,7 @@ class Character(abc.BaseCharacter, abc.Serializable):
 
     # region Private methods
     def _parse_account_information(self, rows):
-        """
-        Parses the character's account information
+        """Parse the character's account information.
 
         Parameters
         ----------
@@ -352,8 +357,7 @@ class Character(abc.BaseCharacter, abc.Serializable):
         self.account_information = AccountInformation(created, loyalty_title, position)
 
     def _parse_achievements(self, rows):
-        """
-        Parses the character's displayed achievements
+        """Parse the character's displayed achievements.
 
         Parameters
         ----------
@@ -374,8 +378,7 @@ class Character(abc.BaseCharacter, abc.Serializable):
             self.achievements.append(Achievement(name, grade, secret))
 
     def _parse_badges(self, rows):
-        """
-        Parses the character's displayed badges
+        """Parse the character's displayed badges.
 
         Parameters
         ----------
@@ -385,23 +388,20 @@ class Character(abc.BaseCharacter, abc.Serializable):
         row = rows[0]
         columns = row.find_all('td')
         for column in columns:
-            popup = column.find("span", attrs={"class": "HelperDivIndicator"})
-            if not popup:
+            popup_span = column.find("span", attrs={"class": "HelperDivIndicator"})
+            if not popup_span:
                 # Badges are visible, but none selected.
                 return
-            m = badge_popup_regexp.search(popup['onmouseover'])
-            if m:
-                name = m.group(1)
-                description = m.group(2)
-            else:
-                continue
+            popup = parse_popup(popup_span['onmouseover'])
+            name = popup[0]
+            description = popup[1].text
             icon_image = column.find("img")
             icon_url = icon_image['src']
             self.account_badges.append(AccountBadge(name, icon_url, description))
 
     def _parse_character_information(self, rows):
         """
-        Parses the character's basic information and applies the found values.
+        Parse the character's basic information and applies the found values.
 
         Parameters
         ----------
@@ -445,7 +445,7 @@ class Character(abc.BaseCharacter, abc.Serializable):
             char["deletion_date"] = parse_tibia_datetime(m.group(2))
 
         if "(traded)" in char["name"]:
-            char["name"] = char["name"].replace("(traded)","").strip()
+            char["name"] = char["name"].replace("(traded)", "").strip()
             char["traded"] = True
 
         if "former_names" in char:
@@ -481,8 +481,7 @@ class Character(abc.BaseCharacter, abc.Serializable):
                        for h in houses]
 
     def _parse_deaths(self, rows):
-        """
-        Parses the character's recent deaths
+        """Parse the character's recent deaths.
 
         Parameters
         ----------
@@ -530,7 +529,7 @@ class Character(abc.BaseCharacter, abc.Serializable):
 
     @classmethod
     def _parse_killer(cls, killer):
-        """Parses a killer into a dictionary.
+        """Parse a killer into a dictionary.
 
         Parameters
         ----------
@@ -554,18 +553,17 @@ class Character(abc.BaseCharacter, abc.Serializable):
         return killer_dict
 
     def _parse_other_characters(self, rows):
-        """
-        Parses the character's other visible characters.
+        """Parse the character's other visible characters.
 
         Parameters
         ----------
         rows: :class:`list` of :class:`bs4.Tag`
             A list of all rows contained in the table.
         """
-        for row in rows:
+        for row in rows[1:]:
             cols_raw = row.find_all('td')
             cols = [ele.text.strip() for ele in cols_raw]
-            if len(cols) != 5:
+            if len(cols) != 4:
                 continue
             name, world, status, *__ = cols
             _, *name = name.replace("\xa0", " ").split(" ")
@@ -587,7 +585,7 @@ class Character(abc.BaseCharacter, abc.Serializable):
     @classmethod
     def _parse_tables(cls, parsed_content):
         """
-        Parses the information tables contained in a character's page.
+        Parse the information tables contained in a character's page.
 
         Parameters
         ----------
@@ -602,15 +600,21 @@ class Character(abc.BaseCharacter, abc.Serializable):
         tables = parsed_content.find_all('table', attrs={"width": "100%"})
         output = OrderedDict()
         for table in tables:
-            title = table.find("td").text
-            output[title] = table.find_all("tr")[1:]
+            container = table.find_parent("div", {"class": "TableContainer"})
+            if container:
+                caption_container = container.find("div", {"class": "CaptionContainer"})
+                title = caption_container.text.strip()
+                offset = 0
+            else:
+                title = table.find("td").text.strip()
+                offset = 1
+            output[title] = table.find_all("tr")[offset:]
         return output
     # endregion
 
 
 class Death(abc.Serializable):
-    """
-    Represents a death by a character
+    """A character's death.
 
     Attributes
     -----------
@@ -625,6 +629,7 @@ class Death(abc.Serializable):
     time: :class:`datetime.datetime`
         The time at which the death occurred.
     """
+
     __slots__ = (
         "level",
         "killers",
@@ -638,11 +643,11 @@ class Death(abc.Serializable):
     )
 
     def __init__(self, name=None, level=0, **kwargs):
-        self.name = name
-        self.level = level
+        self.name: str = name
+        self.level: int = level
         self.killers: List[Killer] = kwargs.get("killers", [])
         self.assists: List[Killer] = kwargs.get("assists", [])
-        self.time = try_datetime(kwargs.get("time"))
+        self.time: datetime.datetime = try_datetime(kwargs.get("time"))
 
     def __repr__(self):
         attributes = ""
@@ -667,14 +672,14 @@ class Death(abc.Serializable):
     def killer(self):
         """:class:`Killer`: The first killer in the list.
 
-        This is usually the killer that gave the killing blow."""
+        This is usually the killer that gave the killing blow.
+        """
         return self.killers[0] if self.killers else None
     # endregion
 
 
 class GuildMembership(abc.BaseGuild, abc.Serializable):
-    """
-    Represents the guild information of a character.
+    """The guild information of a character.
 
     Attributes
     ----------
@@ -682,9 +687,10 @@ class GuildMembership(abc.BaseGuild, abc.Serializable):
         The name of the guild.
     rank: :class:`str`
         The name of the rank the member has.
-    title: :class:`str`
-        The title of the member in the guild.
+    title: :class:`str`, optional
+        The title of the member in the guild. This is only available for characters in the forums section.
     """
+
     __slots__ = (
         "name",
         "rank",
@@ -701,8 +707,7 @@ class GuildMembership(abc.BaseGuild, abc.Serializable):
 
 
 class Killer(abc.Serializable):
-    """
-    Represents a killer.
+    """Represents a killer.
 
     A killer can be:
 
@@ -719,10 +724,11 @@ class Killer(abc.Serializable):
     summon: :class:`str`, optional
         The name of the summoned creature, if applicable.
     """
+
     __slots__ = (
         "name",
         "player",
-        "summon"
+        "summon",
     )
 
     def __init__(self, name, player=False, summon=None):
@@ -731,31 +737,17 @@ class Killer(abc.Serializable):
         self.summon: Optional[str] = summon
 
     def __repr__(self):
-        attributes = ""
-        for attr in self.__slots__:
-            if attr in ["name"]:
-                continue
-            v = getattr(self, attr)
-            if isinstance(v, int) and v == 0 and not isinstance(v, bool):
-                continue
-            if isinstance(v, list) and len(v) == 0:
-                continue
-            if v is None:
-                continue
-            attributes += f",{attr}={v!r}"
-        return f"{self.__class__.__name__}({self.name!r}{attributes})"
+        summon = f" summon={self.summon!r}" if self.summon else ""
+        return f"<{self.__class__.__name__} name={self.name!r} player={self.player}{summon}>"
 
     @property
     def url(self):
-        """
-        :class:`str`, optional: The URL of the character’s information page on Tibia.com, if applicable.
-        """
+        """:class:`str`, optional: The URL of the character’s information page on Tibia.com, if applicable."""
         return Character.get_url(self.name) if self.player else None
 
 
 class OnlineCharacter(abc.BaseCharacter, abc.Serializable):
-    """
-    Represents an online character.
+    """An online character in the world's page.
 
     Attributes
     ----------
@@ -768,6 +760,7 @@ class OnlineCharacter(abc.BaseCharacter, abc.Serializable):
     level: :class:`int`
         The level of the character.
     """
+
     __slots__ = (
         "name",
         "world",
@@ -781,10 +774,14 @@ class OnlineCharacter(abc.BaseCharacter, abc.Serializable):
         self.level = int(level)
         self.vocation = try_enum(Vocation, vocation)
 
+    def __repr__(self):
+        return f"<{self.__class__.__name__} name={self.name!r} level={self.level} vocation={self.vocation!r}>"
+
 
 class OtherCharacter(abc.BaseCharacter, abc.Serializable):
-    """
-    Represents other characters displayed in the Character's information page.
+    """A character listed in the characters section of a character's page.
+
+    These are only shown if the character is not hidden, and only characters that are not hidden are shown here.
 
     Attributes
     ----------
@@ -803,6 +800,7 @@ class OtherCharacter(abc.BaseCharacter, abc.Serializable):
     position: :class:`str`
         The character's official position, if any.
     """
+
     __slots__ = (
         "name",
         "world",
